@@ -12,7 +12,7 @@ def search_tavily(messages: list, **kwargs):
 
     import os
 
-    TAVILY_API_KEY = os.getenv("TAVILY_API_KEY").split(",") if os.getenv("TAVILY_API_KEY") and "," in os.getenv("TAVILY_API_KEY") else [os.getenv("TAVILY_API_KEY")]
+    TAVILY_API_KEY = os.getenv("TAVILY_API_KEY").split(",") if os.getenv("TAVILY_API_KEY") else [""]
 
     if not TAVILY_API_KEY[0]:
         return None
